@@ -46,6 +46,14 @@
 #include <direct.h>
 #endif
 
+#ifdef	HAVE_SYS_INOTIFY_H
+#include <sys/inotify.h>
+#endif
+
+#ifdef	HAVE_SYS_EVENT_H
+#include <sys/event.h>
+#endif
+
 using namespace UCOMMON_NAMESPACE;
 
 const fsys::offset_t fsys::end = (size_t)(-1);
@@ -142,6 +150,17 @@ int fsys::stat(const char *path, struct stat *buf)
 	return 0;
 }
 
+int fsys::trunc(offset_t offset)
+{
+	if(fsys::seek(offset) != 0)
+		return remapError();
+
+	if(SetEndOfFile(fd))
+		return 0;
+
+	return remapError();
+}
+
 int fsys::stat(struct stat *buf)
 {
 	int fn = _open_osfhandle((long int)(fd), _O_RDONLY);
@@ -429,7 +448,7 @@ int fsys::seek(offset_t pos)
 	}
 	return 0;
 }
-
+	
 #else
 
 ssize_t fsys::read(void *buf, size_t len)
@@ -611,6 +630,26 @@ int fsys::stat(const char *path, struct stat *ino)
 	return 0;
 }
 
+#ifdef	HAVE_FTRUNCATE
+int fsys::trunc(offset_t offset)
+{
+	if(fsys::seek(offset) != 0)
+		return remapError();
+
+	if(::ftruncate(fd, offset) == 0)
+		return 0;
+	return remapError();
+}
+#else
+int fsys::trunc(offset_t offset)
+{
+	if(fsys::seek(offset) != 0)
+		return remapError();
+
+	return ENOSYS;
+}
+#endif
+
 int fsys::stat(struct stat *ino)
 {
 	if(::fstat(fd, ino)) {
