@@ -1677,6 +1677,17 @@ ssize_t Socket::sendto(socket_t so, const void *data, size_t len, int flags, str
 	return _sendto_(so, (caddr_t)data, len, MSG_NOSIGNAL | flags, dest, slen);
 }
 
+ssize_t Socket::puts(const char *str, struct sockaddr *address)
+{
+	if(!str)
+		return 0;
+
+	if(!*str)
+		return 0;
+
+	return put(str, strlen(str), address);
+}
+
 ssize_t Socket::puts(const char *str)
 {
 	if(!str)
